//! Autogenerated by GenerateDef from src/aro/Builtins/powerpc.def, do not edit
// zig fmt: off

const std = @import("std");

pub fn with(comptime Properties: type) type {
return struct {

/// Integer starting at 0 derived from the unique index,
/// corresponds with the data array index.
pub const Tag = enum(u16) {    __builtin_addf128_round_to_odd,
    __builtin_addg6s,
    __builtin_altivec_dss,
    __builtin_altivec_dssall,
    __builtin_altivec_dst,
    __builtin_altivec_dstst,
    __builtin_altivec_dststt,
    __builtin_altivec_dstt,
    __builtin_altivec_lvebx,
    __builtin_altivec_lvehx,
    __builtin_altivec_lvewx,
    __builtin_altivec_lvsl,
    __builtin_altivec_lvsr,
    __builtin_altivec_lvx,
    __builtin_altivec_lvxl,
    __builtin_altivec_mfvscr,
    __builtin_altivec_mtvscr,
    __builtin_altivec_mtvsrbm,
    __builtin_altivec_mtvsrdm,
    __builtin_altivec_mtvsrhm,
    __builtin_altivec_mtvsrqm,
    __builtin_altivec_mtvsrwm,
    __builtin_altivec_stvebx,
    __builtin_altivec_stvehx,
    __builtin_altivec_stvewx,
    __builtin_altivec_stvx,
    __builtin_altivec_stvxl,
    __builtin_altivec_vabsduh,
    __builtin_altivec_vabsduw,
    __builtin_altivec_vaddcuw,
    __builtin_altivec_vaddsbs,
    __builtin_altivec_vaddshs,
    __builtin_altivec_vaddsws,
    __builtin_altivec_vaddubs,
    __builtin_altivec_vadduhs,
    __builtin_altivec_vadduws,
    __builtin_altivec_vavgsb,
    __builtin_altivec_vavgsh,
    __builtin_altivec_vavgsw,
    __builtin_altivec_vavgub,
    __builtin_altivec_vavguh,
    __builtin_altivec_vavguw,
    __builtin_altivec_vcfsx,
    __builtin_altivec_vcfux,
    __builtin_altivec_vclrlb,
    __builtin_altivec_vclrrb,
    __builtin_altivec_vclzb,
    __builtin_altivec_vclzd,
    __builtin_altivec_vclzh,
    __builtin_altivec_vclzlsbb,
    __builtin_altivec_vclzw,
    __builtin_altivec_vcmpbfp,
    __builtin_altivec_vcmpbfp_p,
    __builtin_altivec_vcmpeqfp,
    __builtin_altivec_vcmpeqfp_p,
    __builtin_altivec_vcmpequb,
    __builtin_altivec_vcmpequb_p,
    __builtin_altivec_vcmpequd_p,
    __builtin_altivec_vcmpequh,
    __builtin_altivec_vcmpequh_p,
    __builtin_altivec_vcmpequq_p,
    __builtin_altivec_vcmpequw,
    __builtin_altivec_vcmpequw_p,
    __builtin_altivec_vcmpgefp,
    __builtin_altivec_vcmpgefp_p,
    __builtin_altivec_vcmpgtfp,
    __builtin_altivec_vcmpgtfp_p,
    __builtin_altivec_vcmpgtsb,
    __builtin_altivec_vcmpgtsb_p,
    __builtin_altivec_vcmpgtsd_p,
    __builtin_altivec_vcmpgtsh,
    __builtin_altivec_vcmpgtsh_p,
    __builtin_altivec_vcmpgtsw,
    __builtin_altivec_vcmpgtsw_p,
    __builtin_altivec_vcmpgtub,
    __builtin_altivec_vcmpgtub_p,
    __builtin_altivec_vcmpgtud_p,
    __builtin_altivec_vcmpgtuh,
    __builtin_altivec_vcmpgtuh_p,
    __builtin_altivec_vcmpgtuw,
    __builtin_altivec_vcmpgtuw_p,
    __builtin_altivec_vcmpneb,
    __builtin_altivec_vcmpneb_p,
    __builtin_altivec_vcmpned_p,
    __builtin_altivec_vcmpneh,
    __builtin_altivec_vcmpneh_p,
    __builtin_altivec_vcmpnew,
    __builtin_altivec_vcmpnew_p,
    __builtin_altivec_vcmpnezb,
    __builtin_altivec_vcmpnezh,
    __builtin_altivec_vcmpnezw,
    __builtin_altivec_vcntmbb,
    __builtin_altivec_vcntmbd,
    __builtin_altivec_vcntmbh,
    __builtin_altivec_vcntmbw,
    __builtin_altivec_vctsxs,
    __builtin_altivec_vctuxs,
    __builtin_altivec_vctzb,
    __builtin_altivec_vctzd,
    __builtin_altivec_vctzh,
    __builtin_altivec_vctzlsbb,
    __builtin_altivec_vctzw,
    __builtin_altivec_vdivesw,
    __builtin_altivec_vdiveuw,
    __builtin_altivec_vexpandbm,
    __builtin_altivec_vexpandhm,
    __builtin_altivec_vexpandwm,
    __builtin_altivec_vexptefp,
    __builtin_altivec_vextractbm,
    __builtin_altivec_vextractdm,
    __builtin_altivec_vextracthm,
    __builtin_altivec_vextractqm,
    __builtin_altivec_vextractwm,
    __builtin_altivec_vextsb2d,
    __builtin_altivec_vextsb2w,
    __builtin_altivec_vextsh2d,
    __builtin_altivec_vextsh2w,
    __builtin_altivec_vextsw2d,
    __builtin_altivec_vgbbd,
    __builtin_altivec_vgnb,
    __builtin_altivec_vinshlx,
    __builtin_altivec_vinshrx,
    __builtin_altivec_vinsw,
    __builtin_altivec_vinswlx,
    __builtin_altivec_vinswrx,
    __builtin_altivec_vlogefp,
    __builtin_altivec_vmaddfp,
    __builtin_altivec_vmaxfp,
    __builtin_altivec_vmaxsb,
    __builtin_altivec_vmaxsd,
    __builtin_altivec_vmaxsh,
    __builtin_altivec_vmaxsw,
    __builtin_altivec_vmaxub,
    __builtin_altivec_vmaxuh,
    __builtin_altivec_vmaxuw,
    __builtin_altivec_vmhaddshs,
    __builtin_altivec_vmhraddshs,
    __builtin_altivec_vminfp,
    __builtin_altivec_vminsb,
    __builtin_altivec_vminsd,
    __builtin_altivec_vminsh,
    __builtin_altivec_vminsw,
    __builtin_altivec_vminub,
    __builtin_altivec_vminuh,
    __builtin_altivec_vminuw,
    __builtin_altivec_vmsummbm,
    __builtin_altivec_vmsumshm,
    __builtin_altivec_vmsumshs,
    __builtin_altivec_vmsumubm,
    __builtin_altivec_vmsumuhm,
    __builtin_altivec_vmsumuhs,
    __builtin_altivec_vmulesb,
    __builtin_altivec_vmulesh,
    __builtin_altivec_vmulesw,
    __builtin_altivec_vmuleub,
    __builtin_altivec_vmuleuh,
    __builtin_altivec_vmuleuw,
    __builtin_altivec_vmulhsw,
    __builtin_altivec_vmulhuw,
    __builtin_altivec_vmulosb,
    __builtin_altivec_vmulosh,
    __builtin_altivec_vmulosw,
    __builtin_altivec_vmuloub,
    __builtin_altivec_vmulouh,
    __builtin_altivec_vmulouw,
    __builtin_altivec_vnmsubfp,
    __builtin_altivec_vperm_4si,
    __builtin_altivec_vpkpx,
    __builtin_altivec_vpkshss,
    __builtin_altivec_vpkshus,
    __builtin_altivec_vpkswss,
    __builtin_altivec_vpkswus,
    __builtin_altivec_vpkuhus,
    __builtin_altivec_vpkuwus,
    __builtin_altivec_vprtybd,
    __builtin_altivec_vprtybq,
    __builtin_altivec_vprtybw,
    __builtin_altivec_vrefp,
    __builtin_altivec_vrfim,
    __builtin_altivec_vrfin,
    __builtin_altivec_vrfip,
    __builtin_altivec_vrfiz,
    __builtin_altivec_vrlb,
    __builtin_altivec_vrld,
    __builtin_altivec_vrlh,
    __builtin_altivec_vrlw,
    __builtin_altivec_vrlwnm,
    __builtin_altivec_vrsqrtefp,
    __builtin_altivec_vsel_4si,
    __builtin_altivec_vsl,
    __builtin_altivec_vslo,
    __builtin_altivec_vslv,
    __builtin_altivec_vsr,
    __builtin_altivec_vsrab,
    __builtin_altivec_vsrah,
    __builtin_altivec_vsraw,
    __builtin_altivec_vsro,
    __builtin_altivec_vsrv,
    __builtin_altivec_vstribl,
    __builtin_altivec_vstribl_p,
    __builtin_altivec_vstribr,
    __builtin_altivec_vstribr_p,
    __builtin_altivec_vstrihl,
    __builtin_altivec_vstrihl_p,
    __builtin_altivec_vstrihr,
    __builtin_altivec_vstrihr_p,
    __builtin_altivec_vsubcuw,
    __builtin_altivec_vsubsbs,
    __builtin_altivec_vsubshs,
    __builtin_altivec_vsubsws,
    __builtin_altivec_vsububs,
    __builtin_altivec_vsubuhs,
    __builtin_altivec_vsubuws,
    __builtin_altivec_vsum2sws,
    __builtin_altivec_vsum4sbs,
    __builtin_altivec_vsum4shs,
    __builtin_altivec_vsum4ubs,
    __builtin_altivec_vsumsws,
    __builtin_altivec_vupkhpx,
    __builtin_altivec_vupkhsb,
    __builtin_altivec_vupkhsh,
    __builtin_altivec_vupkhsw,
    __builtin_altivec_vupklpx,
    __builtin_altivec_vupklsb,
    __builtin_altivec_vupklsh,
    __builtin_altivec_vupklsw,
    __builtin_bpermd,
    __builtin_cbcdtd,
    __builtin_cdtbcd,
    __builtin_cfuged,
    __builtin_cntlzdm,
    __builtin_cnttzdm,
    __builtin_darn,
    __builtin_darn_32,
    __builtin_darn_raw,
    __builtin_dcbf,
    __builtin_divde,
    __builtin_divdeu,
    __builtin_divf128_round_to_odd,
    __builtin_divwe,
    __builtin_divweu,
    __builtin_fmaf128_round_to_odd,
    __builtin_get_texasr,
    __builtin_get_texasru,
    __builtin_get_tfhar,
    __builtin_get_tfiar,
    __builtin_mma_assemble_acc,
    __builtin_mma_assemble_pair,
    __builtin_mma_build_acc,
    __builtin_mma_disassemble_acc,
    __builtin_mma_disassemble_pair,
    __builtin_mma_dmxvi8gerx4,
    __builtin_mma_dmxvi8gerx4pp,
    __builtin_mma_dmxvi8gerx4spp,
    __builtin_mma_lxvp,
    __builtin_mma_pmdmxvi8gerx4,
    __builtin_mma_pmdmxvi8gerx4pp,
    __builtin_mma_pmdmxvi8gerx4spp,
    __builtin_mma_pmxvbf16ger2,
    __builtin_mma_pmxvf16ger2,
    __builtin_mma_pmxvf32ger,
    __builtin_mma_pmxvf64ger,
    __builtin_mma_pmxvi16ger2,
    __builtin_mma_pmxvi16ger2pp,
    __builtin_mma_pmxvi16ger2s,
    __builtin_mma_pmxvi16ger2spp,
    __builtin_mma_pmxvi4ger8,
    __builtin_mma_pmxvi4ger8pp,
    __builtin_mma_pmxvi8ger4,
    __builtin_mma_pmxvi8ger4pp,
    __builtin_mma_pmxvi8ger4spp,
    __builtin_mma_stxvp,
    __builtin_mma_xvbf16ger2,
    __builtin_mma_xvf16ger2,
    __builtin_mma_xvf32ger,
    __builtin_mma_xvf64ger,
    __builtin_mma_xvi16ger2,
    __builtin_mma_xvi16ger2pp,
    __builtin_mma_xvi16ger2s,
    __builtin_mma_xvi16ger2spp,
    __builtin_mma_xvi4ger8,
    __builtin_mma_xvi4ger8pp,
    __builtin_mma_xvi8ger4,
    __builtin_mma_xvi8ger4pp,
    __builtin_mma_xvi8ger4spp,
    __builtin_mma_xxmfacc,
    __builtin_mma_xxmtacc,
    __builtin_mma_xxsetaccz,
    __builtin_mulf128_round_to_odd,
    __builtin_pack_longdouble,
    __builtin_pack_vector_int128,
    __builtin_pdepd,
    __builtin_pextd,
    __builtin_ppc_addex,
    __builtin_ppc_addg6s,
    __builtin_ppc_alignx,
    __builtin_ppc_cbcdtd,
    __builtin_ppc_cdtbcd,
    __builtin_ppc_cmpb,
    __builtin_ppc_cmpeqb,
    __builtin_ppc_cmprb,
    __builtin_ppc_compare_and_swap,
    __builtin_ppc_compare_and_swaplp,
    __builtin_ppc_compare_exp_eq,
    __builtin_ppc_compare_exp_gt,
    __builtin_ppc_compare_exp_lt,
    __builtin_ppc_compare_exp_uo,
    __builtin_ppc_dcbfl,
    __builtin_ppc_dcbflp,
    __builtin_ppc_dcbst,
    __builtin_ppc_dcbt,
    __builtin_ppc_dcbtst,
    __builtin_ppc_dcbtstt,
    __builtin_ppc_dcbtt,
    __builtin_ppc_dcbz,
    __builtin_ppc_eieio,
    __builtin_ppc_extract_exp,
    __builtin_ppc_extract_sig,
    __builtin_ppc_fcfid,
    __builtin_ppc_fcfud,
    __builtin_ppc_fctid,
    __builtin_ppc_fctidz,
    __builtin_ppc_fctiw,
    __builtin_ppc_fctiwz,
    __builtin_ppc_fctudz,
    __builtin_ppc_fctuwz,
    __builtin_ppc_fence,
    __builtin_ppc_fetch_and_add,
    __builtin_ppc_fetch_and_addlp,
    __builtin_ppc_fetch_and_and,
    __builtin_ppc_fetch_and_andlp,
    __builtin_ppc_fetch_and_or,
    __builtin_ppc_fetch_and_orlp,
    __builtin_ppc_fetch_and_swap,
    __builtin_ppc_fetch_and_swaplp,
    __builtin_ppc_fmsub,
    __builtin_ppc_fmsubs,
    __builtin_ppc_fnabs,
    __builtin_ppc_fnabss,
    __builtin_ppc_fnmadd,
    __builtin_ppc_fnmadds,
    __builtin_ppc_fnmsub,
    __builtin_ppc_fnmsubs,
    __builtin_ppc_fre,
    __builtin_ppc_fres,
    __builtin_ppc_fric,
    __builtin_ppc_frim,
    __builtin_ppc_frims,
    __builtin_ppc_frin,
    __builtin_ppc_frins,
    __builtin_ppc_frip,
    __builtin_ppc_frips,
    __builtin_ppc_friz,
    __builtin_ppc_frizs,
    __builtin_ppc_frsqrte,
    __builtin_ppc_frsqrtes,
    __builtin_ppc_fsel,
    __builtin_ppc_fsels,
    __builtin_ppc_fsqrt,
    __builtin_ppc_fsqrts,
    __builtin_ppc_get_timebase,
    __builtin_ppc_icbt,
    __builtin_ppc_insert_exp,
    __builtin_ppc_iospace_eieio,
    __builtin_ppc_iospace_lwsync,
    __builtin_ppc_iospace_sync,
    __builtin_ppc_isync,
    __builtin_ppc_lbarx,
    __builtin_ppc_ldarx,
    __builtin_ppc_lharx,
    __builtin_ppc_load2r,
    __builtin_ppc_load4r,
    __builtin_ppc_load8r,
    __builtin_ppc_lwarx,
    __builtin_ppc_lwsync,
    __builtin_ppc_maddhd,
    __builtin_ppc_maddld,
    __builtin_ppc_maxfe,
    __builtin_ppc_maxfl,
    __builtin_ppc_maxfs,
    __builtin_ppc_mffs,
    __builtin_ppc_mffsl,
    __builtin_ppc_mfmsr,
    __builtin_ppc_mfspr,
    __builtin_ppc_mftbu,
    __builtin_ppc_minfe,
    __builtin_ppc_minfl,
    __builtin_ppc_minfs,
    __builtin_ppc_mtfsb0,
    __builtin_ppc_mtfsb1,
    __builtin_ppc_mtfsf,
    __builtin_ppc_mtfsfi,
    __builtin_ppc_mtmsr,
    __builtin_ppc_mtspr,
    __builtin_ppc_mulhd,
    __builtin_ppc_mulhdu,
    __builtin_ppc_mulhw,
    __builtin_ppc_mulhwu,
    __builtin_ppc_national2packed,
    __builtin_ppc_packed2national,
    __builtin_ppc_packed2zoned,
    __builtin_ppc_popcntb,
    __builtin_ppc_poppar4,
    __builtin_ppc_poppar8,
    __builtin_ppc_rdlam,
    __builtin_ppc_recipdivd,
    __builtin_ppc_recipdivf,
    __builtin_ppc_rldimi,
    __builtin_ppc_rlwimi,
    __builtin_ppc_rlwnm,
    __builtin_ppc_rsqrtd,
    __builtin_ppc_rsqrtf,
    __builtin_ppc_set_fpscr_rn,
    __builtin_ppc_setb,
    __builtin_ppc_stbcx,
    __builtin_ppc_stdcx,
    __builtin_ppc_stfiw,
    __builtin_ppc_sthcx,
    __builtin_ppc_store2r,
    __builtin_ppc_store4r,
    __builtin_ppc_store8r,
    __builtin_ppc_stwcx,
    __builtin_ppc_swdiv,
    __builtin_ppc_swdiv_nochk,
    __builtin_ppc_swdivs,
    __builtin_ppc_swdivs_nochk,
    __builtin_ppc_sync,
    __builtin_ppc_tdw,
    __builtin_ppc_test_data_class,
    __builtin_ppc_trap,
    __builtin_ppc_trapd,
    __builtin_ppc_tw,
    __builtin_ppc_zoned2packed,
    __builtin_readflm,
    __builtin_set_texasr,
    __builtin_set_texasru,
    __builtin_set_tfhar,
    __builtin_set_tfiar,
    __builtin_setflm,
    __builtin_setrnd,
    __builtin_sqrtf128_round_to_odd,
    __builtin_subf128_round_to_odd,
    __builtin_tabort,
    __builtin_tabortdc,
    __builtin_tabortdci,
    __builtin_tabortwc,
    __builtin_tabortwci,
    __builtin_tbegin,
    __builtin_tcheck,
    __builtin_tend,
    __builtin_tendall,
    __builtin_trechkpt,
    __builtin_treclaim,
    __builtin_tresume,
    __builtin_truncf128_round_to_odd,
    __builtin_tsr,
    __builtin_tsuspend,
    __builtin_ttest,
    __builtin_unpack_longdouble,
    __builtin_unpack_vector_int128,
    __builtin_vsx_assemble_pair,
    __builtin_vsx_build_pair,
    __builtin_vsx_disassemble_pair,
    __builtin_vsx_extractuword,
    __builtin_vsx_insertword,
    __builtin_vsx_ldrmb,
    __builtin_vsx_lxvd2x,
    __builtin_vsx_lxvd2x_be,
    __builtin_vsx_lxvl,
    __builtin_vsx_lxvll,
    __builtin_vsx_lxvp,
    __builtin_vsx_lxvw4x,
    __builtin_vsx_lxvw4x_be,
    __builtin_vsx_scalar_extract_expq,
    __builtin_vsx_scalar_insert_exp_qp,
    __builtin_vsx_strmb,
    __builtin_vsx_stxvd2x,
    __builtin_vsx_stxvd2x_be,
    __builtin_vsx_stxvl,
    __builtin_vsx_stxvll,
    __builtin_vsx_stxvp,
    __builtin_vsx_stxvw4x,
    __builtin_vsx_stxvw4x_be,
    __builtin_vsx_xsmaxdp,
    __builtin_vsx_xsmindp,
    __builtin_vsx_xvabsdp,
    __builtin_vsx_xvabssp,
    __builtin_vsx_xvcmpeqdp,
    __builtin_vsx_xvcmpeqdp_p,
    __builtin_vsx_xvcmpeqsp,
    __builtin_vsx_xvcmpeqsp_p,
    __builtin_vsx_xvcmpgedp,
    __builtin_vsx_xvcmpgedp_p,
    __builtin_vsx_xvcmpgesp,
    __builtin_vsx_xvcmpgesp_p,
    __builtin_vsx_xvcmpgtdp,
    __builtin_vsx_xvcmpgtdp_p,
    __builtin_vsx_xvcmpgtsp,
    __builtin_vsx_xvcmpgtsp_p,
    __builtin_vsx_xvcpsgndp,
    __builtin_vsx_xvcpsgnsp,
    __builtin_vsx_xvcvbf16spn,
    __builtin_vsx_xvcvdpsp,
    __builtin_vsx_xvcvdpsxws,
    __builtin_vsx_xvcvdpuxws,
    __builtin_vsx_xvcvhpsp,
    __builtin_vsx_xvcvspbf16,
    __builtin_vsx_xvcvspdp,
    __builtin_vsx_xvcvsphp,
    __builtin_vsx_xvcvspsxds,
    __builtin_vsx_xvcvspuxds,
    __builtin_vsx_xvcvsxdsp,
    __builtin_vsx_xvcvsxwdp,
    __builtin_vsx_xvcvuxdsp,
    __builtin_vsx_xvcvuxwdp,
    __builtin_vsx_xvdivdp,
    __builtin_vsx_xvdivsp,
    __builtin_vsx_xviexpdp,
    __builtin_vsx_xviexpsp,
    __builtin_vsx_xvmaddadp,
    __builtin_vsx_xvmaddasp,
    __builtin_vsx_xvmaxdp,
    __builtin_vsx_xvmaxsp,
    __builtin_vsx_xvmindp,
    __builtin_vsx_xvminsp,
    __builtin_vsx_xvmsubadp,
    __builtin_vsx_xvmsubasp,
    __builtin_vsx_xvmuldp,
    __builtin_vsx_xvmulsp,
    __builtin_vsx_xvnmaddadp,
    __builtin_vsx_xvnmaddasp,
    __builtin_vsx_xvnmsubadp,
    __builtin_vsx_xvnmsubasp,
    __builtin_vsx_xvrdpi,
    __builtin_vsx_xvrdpic,
    __builtin_vsx_xvrdpim,
    __builtin_vsx_xvrdpip,
    __builtin_vsx_xvrdpiz,
    __builtin_vsx_xvredp,
    __builtin_vsx_xvresp,
    __builtin_vsx_xvrspi,
    __builtin_vsx_xvrspic,
    __builtin_vsx_xvrspim,
    __builtin_vsx_xvrspip,
    __builtin_vsx_xvrspiz,
    __builtin_vsx_xvrsqrtedp,
    __builtin_vsx_xvrsqrtesp,
    __builtin_vsx_xvsqrtdp,
    __builtin_vsx_xvsqrtsp,
    __builtin_vsx_xvtdivdp,
    __builtin_vsx_xvtdivsp,
    __builtin_vsx_xvtlsbb,
    __builtin_vsx_xvtsqrtdp,
    __builtin_vsx_xvtsqrtsp,
    __builtin_vsx_xvtstdcdp,
    __builtin_vsx_xvtstdcsp,
    __builtin_vsx_xvxexpdp,
    __builtin_vsx_xvxexpsp,
    __builtin_vsx_xvxsigdp,
    __builtin_vsx_xvxsigsp,
    __builtin_vsx_xxgenpcvbm,
    __builtin_vsx_xxgenpcvdm,
    __builtin_vsx_xxgenpcvhm,
    __builtin_vsx_xxgenpcvwm,
    __builtin_vsx_xxleqv,
    __builtin_vsx_xxpermdi,
    __builtin_vsx_xxsldwi,
};

pub fn fromName(name: []const u8) ?Properties {
    const data_index = tagFromName(name) orelse return null;
    return data[@intFromEnum(data_index)];
}

pub fn tagFromName(name: []const u8) ?Tag {
    const unique_index = uniqueIndex(name) orelse return null;
    return @enumFromInt(unique_index - 1);
}

pub fn fromTag(tag: Tag) Properties {
    return data[@intFromEnum(tag)];
}

pub fn nameFromTagIntoBuf(tag: Tag, name_buf: []u8) []u8 {
    std.debug.assert(name_buf.len >= longest_name);
    const unique_index = @intFromEnum(tag) + 1;
    return nameFromUniqueIndex(unique_index, name_buf);
}

pub fn nameFromTag(tag: Tag) NameBuf {
    var name_buf: NameBuf = undefined;
    const unique_index = @intFromEnum(tag) + 1;
    const name = nameFromUniqueIndex(unique_index, &name_buf.buf);
    name_buf.len = @intCast(name.len);
    return name_buf;
}

pub const NameBuf = struct {
    buf: [longest_name]u8 = undefined,
    len: std.math.IntFittingRange(0, longest_name),

    pub fn span(self: *const NameBuf) []const u8 {
        return self.buf[0..self.len];
    }
};

pub fn exists(name: []const u8) bool {
    if (name.len < shortest_name or name.len > longest_name) return false;

    var index: u16 = 0;
    for (name) |c| {
        index = findInList(dafsa[index].child_index, c) orelse return false;
    }
    return dafsa[index].end_of_word;
}

pub const shortest_name = 13;
pub const longest_name = 34;

/// Search siblings of `first_child_index` for the `char`
/// If found, returns the index of the node within the `dafsa` array.
/// Otherwise, returns `null`.
pub fn findInList(first_child_index: u16, char: u8) ?u16 {
    @setEvalBranchQuota(1134);
    var index = first_child_index;
    while (true) {
        if (dafsa[index].char == char) return index;
        if (dafsa[index].end_of_list) return null;
        index += 1;
    }
    unreachable;
}

/// Returns a unique (minimal perfect hash) index (starting at 1) for the `name`,
/// or null if the name was not found.
pub fn uniqueIndex(name: []const u8) ?u16 {
    if (name.len < shortest_name or name.len > longest_name) return null;

    var index: u16 = 0;
    var node_index: u16 = 0;

    for (name) |c| {
        const child_index = findInList(dafsa[node_index].child_index, c) orelse return null;
        var sibling_index = dafsa[node_index].child_index;
        while (true) {
            const sibling_c = dafsa[sibling_index].char;
            std.debug.assert(sibling_c != 0);
            if (sibling_c < c) {
                index += dafsa[sibling_index].number;
            }
            if (dafsa[sibling_index].end_of_list) break;
            sibling_index += 1;
        }
        node_index = child_index;
        if (dafsa[node_index].end_of_word) index += 1;
    }

    if (!dafsa[node_index].end_of_word) return null;

    return index;
}

/// Returns a slice of `buf` with the name associated with the given `index`.
/// This function should only be called with an `index` that
/// is already known to exist within the `dafsa`, e.g. an index
/// returned from `uniqueIndex`.
pub fn nameFromUniqueIndex(index: u16, buf: []u8) []u8 {
    std.debug.assert(index >= 1 and index <= data.len);

    var node_index: u16 = 0;
    var count: u16 = index;
    var w = std.Io.Writer.fixed(buf);

    while (true) {
        var sibling_index = dafsa[node_index].child_index;
        while (true) {
            if (dafsa[sibling_index].number > 0 and dafsa[sibling_index].number < count) {
                count -= dafsa[sibling_index].number;
            } else {
                w.writeByte(dafsa[sibling_index].char) catch unreachable;
                node_index = sibling_index;
                if (dafsa[node_index].end_of_word) {
                    count -= 1;
                }
                break;
            }

            if (dafsa[sibling_index].end_of_list) break;
            sibling_index += 1;
        }
        if (count == 0) break;
    }

    return w.buffered();
}

const Node = packed struct {
    char: u8,
    /// Nodes are numbered with "an integer which gives the number of words that
    /// would be accepted by the automaton starting from that state." This numbering
    /// allows calculating "a one-to-one correspondence between the integers 1 to L
    /// (L is the number of words accepted by the automaton) and the words themselves."
    ///
    /// Essentially, this allows us to have a minimal perfect hashing scheme such that
    /// it's possible to store & lookup the properties of each builtin using a separate array.
    number: std.math.IntFittingRange(0, data.len),
    /// If true, this node is the end of a valid builtin.
    /// Note: This does not necessarily mean that this node does not have child nodes.
    end_of_word: bool,
    /// If true, this node is the end of a sibling list.
    /// If false, then (index + 1) will contain the next sibling.
    end_of_list: bool,
    /// Index of the first child of this node.
    child_index: u16,
};

const dafsa = [_]Node{
    .{ .char = 0, .end_of_word = false, .end_of_list = true, .number = 0, .child_index = 1 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 567, .child_index = 2 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 567, .child_index = 3 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 567, .child_index = 4 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 567, .child_index = 5 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 567, .child_index = 6 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 567, .child_index = 7 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 567, .child_index = 8 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 567, .child_index = 9 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 567, .child_index = 10 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 567, .child_index = 11 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 226, .child_index = 24 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 26 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 27 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 9, .child_index = 31 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 34 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 35 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 43, .child_index = 36 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = false, .number = 144, .child_index = 38 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 42 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 8, .child_index = 43 },
    .{ .char = 't', .end_of_word = false, .end_of_list = false, .number = 16, .child_index = 46 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 53 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 107, .child_index = 54 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 55 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 224, .child_index = 56 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 57 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 58 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 59 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 60 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 61 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 62 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 63 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 64 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 65 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 66 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 42, .child_index = 67 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 68 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 69 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 70 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 71 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 140, .child_index = 72 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 73 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 6, .child_index = 74 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 75 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 76 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 77 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 78 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 79 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 80 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 81 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 83 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 85 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 86 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 107, .child_index = 87 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 88 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 224, .child_index = 90 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 91 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 92 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 93 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 94 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 95 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 97 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 98 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 99 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 102 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 103 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 42, .child_index = 104 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 102 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 105 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 106 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 107 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 140, .child_index = 108 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 109 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 110 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 113 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 102 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 114 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 115 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 116 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 117 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 118 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 120 },
    .{ .char = 'r', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 121 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 122 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 123 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 107, .child_index = 124 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 125 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 126 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 224, .child_index = 127 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 128 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 107 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 129 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 130 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 131 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 131 },
    .{ .char = 'n', .end_of_word = true, .end_of_list = true, .number = 3, .child_index = 132 },
    .{ .char = 'f', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 133 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 125 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 133 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 125 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 134 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 42, .child_index = 135 },
    .{ .char = 'k', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 142 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 143 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 143 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 140, .child_index = 144 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 159 },
    .{ .char = '_', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 134 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 160 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 161 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 102 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 162 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 163 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 164 },
    .{ .char = 'd', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 165 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 166 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 168 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 169 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 170 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 171 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 69 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 107, .child_index = 172 },
    .{ .char = '1', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 180 },
    .{ .char = '6', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 181 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 224, .child_index = 182 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 143 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 143 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 143 },
    .{ .char = 'z', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 183 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 184 },
    .{ .char = 'e', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 186 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 187 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 189 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 190 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 191 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 193 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = false, .number = 16, .child_index = 194 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 195 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 16, .child_index = 196 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 198 },
    .{ .char = 'd', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 200 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = false, .number = 11, .child_index = 202 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 8, .child_index = 206 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 207 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 42, .child_index = 209 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 215 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = false, .number = 6, .child_index = 216 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 8, .child_index = 220 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 23, .child_index = 225 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 230 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 231 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = false, .number = 8, .child_index = 233 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 15, .child_index = 237 },
    .{ .char = 't', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 241 },
    .{ .char = 'z', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 245 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 160 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 246 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 143 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 247 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 248 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 249 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 250 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 251 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 252 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 253 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 102 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 254 },
    .{ .char = 't', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 255 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 256 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 257 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 258 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 259 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 8, .child_index = 260 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 10, .child_index = 262 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 84, .child_index = 264 },
    .{ .char = '2', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 267 },
    .{ .char = 's', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 224, .child_index = 268 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 246 },
    .{ .char = '3', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 269 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 270 },
    .{ .char = 'u', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 271 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 272 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 274 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 275 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 276 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 277 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 278 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 16, .child_index = 279 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 193 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = false, .number = 13, .child_index = 281 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 284 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 286 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 287 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 288 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 289 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 58 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 59 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 290 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 291 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 292 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 293 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 294 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = false, .number = 8, .child_index = 295 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 9, .child_index = 297 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 299 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = false, .number = 6, .child_index = 300 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = false, .number = 13, .child_index = 302 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 305 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 307 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 308 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 309 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 310 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 311 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 312 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 312 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 312 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 313 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 314 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 316 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 318 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 322 },
    .{ .char = 't', .end_of_word = false, .end_of_list = false, .number = 6, .child_index = 323 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 326 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 327 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 328 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 329 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 330 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 331 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 332 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 334 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 335 },
    .{ .char = 't', .end_of_word = false, .end_of_list = false, .number = 8, .child_index = 336 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 342 },
    .{ .char = 'y', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 343 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 344 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 345 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 346 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 347 },
    .{ .char = 'm', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 't', .end_of_word = true, .end_of_list = true, .number = 5, .child_index = 348 },
    .{ .char = 'n', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'k', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 350 },
    .{ .char = 'k', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 351 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 352 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 353 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 161 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 354 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 355 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 356 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 357 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 358 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 359 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 7, .child_index = 360 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 361 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 362 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 364 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = false, .number = 75, .child_index = 365 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 7, .child_index = 375 },
    .{ .char = '8', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 379 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 224, .child_index = 380 },
    .{ .char = '2', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 344 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 381 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 382 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 382 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 383 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 384 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 385 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 386 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 387 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 388 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 13, .child_index = 389 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 390 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 391 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 9, .child_index = 394 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 397 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 399 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 400 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 401 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 402 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 404 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 405 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 408 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 409 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 413 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 414 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 415 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 417 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 419 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 420 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 421 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 422 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 423 },
    .{ .char = 'e', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 425 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = false, .number = 9, .child_index = 426 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 431 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 432 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 433 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 434 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 171 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 435 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 436 },
    .{ .char = 'y', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 343 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 437 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 438 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 437 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 311 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 439 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 440 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 441 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 442 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 443 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 444 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 440 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 445 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 442 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 443 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 446 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 447 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 448 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 449 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 451 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 452 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 453 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 454 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 456 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 457 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 459 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 459 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 460 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 459 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 461 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 459 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 462 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 463 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 464 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 465 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 466 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 467 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 467 },
    .{ .char = 'l', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 171 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 246 },
    .{ .char = 'e', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 468 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 469 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 470 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 471 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 472 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 473 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 7, .child_index = 474 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 478 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 473 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 7, .child_index = 360 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 479 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 481 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = false, .number = 28, .child_index = 482 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 485 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 486 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 10, .child_index = 487 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 491 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = false, .number = 14, .child_index = 492 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 495 },
    .{ .char = 't', .end_of_word = false, .end_of_list = false, .number = 7, .child_index = 496 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 499 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 501 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 502 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 503 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 504 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 505 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 224, .child_index = 506 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 511 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 512 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 513 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 514 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 189 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 515 },
    .{ .char = 'p', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 277 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 13, .child_index = 281 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 516 },
    .{ .char = '1', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 517 },
    .{ .char = '3', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 518 },
    .{ .char = '6', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 519 },
    .{ .char = '1', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 520 },
    .{ .char = '4', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 521 },
    .{ .char = '8', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 522 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 523 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 523 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 524 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 525 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 526 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 527 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 126 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 528 },
    .{ .char = 'b', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 529 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 530 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 531 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 532 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 171 },
    .{ .char = 't', .end_of_word = true, .end_of_list = false, .number = 4, .child_index = 533 },
    .{ .char = 'z', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 535 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 536 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 143 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 143 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 537 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 539 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 353 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 541 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 542 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 543 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 544 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 421 },
    .{ .char = 's', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'c', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'm', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 425 },
    .{ .char = 'n', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 425 },
    .{ .char = 'p', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 425 },
    .{ .char = 'z', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 425 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 545 },
    .{ .char = 'l', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 425 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 546 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 547 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 548 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 549 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 527 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 550 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 553 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 555 },
    .{ .char = 's', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 558 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 512 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 512 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 559 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 560 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 562 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 564 },
    .{ .char = 'k', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 565 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 566 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 567 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 246 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 568 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 569 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 569 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 246 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 570 },
    .{ .char = '_', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 571 },
    .{ .char = 'b', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 527 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 344 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 572 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 573 },
    .{ .char = 'c', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 574 },
    .{ .char = 'p', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 575 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 576 },
    .{ .char = 'c', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 577 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 578 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 579 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 255 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 580 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 581 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 530 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 582 },
    .{ .char = 'l', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 558 },
    .{ .char = 'p', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 583 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 584 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 585 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 586 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 587 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 12, .child_index = 588 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 589 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 14, .child_index = 590 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 595 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 596 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 597 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 599 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 600 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 601 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 602 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 604 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 605 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 7, .child_index = 607 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 609 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 485 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 610 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 611 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 596 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 613 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 614 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 615 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 616 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 617 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 618 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 6, .child_index = 619 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 7, .child_index = 620 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 7, .child_index = 621 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 623 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 199, .child_index = 624 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 637 },
    .{ .char = 'r', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 638 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 639 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 640 },
    .{ .char = '1', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 517 },
    .{ .char = '6', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 641 },
    .{ .char = '2', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 642 },
    .{ .char = '4', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 642 },
    .{ .char = '6', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 643 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 644 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 645 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 646 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 647 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 648 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 649 },
    .{ .char = 'x', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 527 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 530 },
    .{ .char = 'b', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 650 },
    .{ .char = 'l', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 651 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 652 },
    .{ .char = 't', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'o', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 653 },
    .{ .char = 'd', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 654 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 654 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 655 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 655 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 656 },
    .{ .char = 'b', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 425 },
    .{ .char = 's', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 425 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 657 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 658 },
    .{ .char = 't', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 425 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 659 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 660 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 661 },
    .{ .char = '2', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 512 },
    .{ .char = '4', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 512 },
    .{ .char = '8', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 512 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 143 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 143 },
    .{ .char = 'e', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'l', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 's', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'l', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'u', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 662 },
    .{ .char = 'f', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 577 },
    .{ .char = 'd', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 186 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 186 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 664 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 665 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 666 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 667 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 668 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 669 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 670 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 672 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 550 },
    .{ .char = 'v', .end_of_word = true, .end_of_list = true, .number = 4, .child_index = 673 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 675 },
    .{ .char = 'd', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 676 },
    .{ .char = 'i', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 677 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 678 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 679 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 680 },
    .{ .char = '2', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 681 },
    .{ .char = '4', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 681 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 682 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 683 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 683 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 605 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 12, .child_index = 684 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 686 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 687 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 688 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 689 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 7, .child_index = 690 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 692 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 605 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 693 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 694 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 605 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 605 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 695 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 605 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 696 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 600 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 697 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 387 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 387 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 697 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 698 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 699 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 700 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 609 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 701 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 702 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 703 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 704 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 705 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 706 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 707 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 708 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 7, .child_index = 710 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 713 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 714 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 715 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 15, .child_index = 716 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = false, .number = 60, .child_index = 719 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 724 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 14, .child_index = 725 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 726 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 728 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 729 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 39, .child_index = 730 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 735 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = false, .number = 11, .child_index = 736 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = false, .number = 11, .child_index = 739 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 30, .child_index = 743 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 748 },
    .{ .char = 'r', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 186 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 749 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 523 },
    .{ .char = '8', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 750 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 751 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 752 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 753 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 754 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 755 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 463 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 756 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 757 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 758 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 759 },
    .{ .char = 'p', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 't', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 760 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 761 },
    .{ .char = 'z', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'z', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 762 },
    .{ .char = 'd', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 425 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 763 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 764 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 765 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 766 },
    .{ .char = '0', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = '1', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 767 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 768 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 530 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 769 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 771 },
    .{ .char = 'i', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'd', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'f', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 772 },
    .{ .char = '_', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 773 },
    .{ .char = 's', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 774 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 775 },
    .{ .char = '2', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 776 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 777 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 778 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 779 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 780 },
    .{ .char = 'x', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 781 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 782 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 387 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 783 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 784 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 599 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 786 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 787 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 789 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 790 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 795 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 795 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 605 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 797 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 797 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 694 },
    .{ .char = 'i', .end_of_word = true, .end_of_list = true, .number = 5, .child_index = 798 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 802 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 605 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 530 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 803 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 605 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 804 },
    .{ .char = 'v', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 805 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 669 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 806 },
    .{ .char = 's', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 165 },
    .{ .char = 't', .end_of_word = true, .end_of_list = true, .number = 4, .child_index = 533 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 807 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 810 },
    .{ .char = 'x', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 558 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 812 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 813 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 814 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 816 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 7, .child_index = 817 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 818 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 819 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 7, .child_index = 821 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 40, .child_index = 823 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 824 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 7, .child_index = 825 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 828 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 14, .child_index = 829 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 831 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 530 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 832 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 833 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 9, .child_index = 834 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 836 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = false, .number = 8, .child_index = 838 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 6, .child_index = 839 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 14, .child_index = 840 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 841 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 842 },
    .{ .char = 'k', .end_of_word = false, .end_of_list = false, .number = 7, .child_index = 843 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 846 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 847 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 848 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 849 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 853 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 854 },
    .{ .char = 'l', .end_of_word = true, .end_of_list = false, .number = 3, .child_index = 855 },
    .{ .char = 'r', .end_of_word = true, .end_of_list = false, .number = 6, .child_index = 857 },
    .{ .char = 't', .end_of_word = false, .end_of_list = false, .number = 8, .child_index = 860 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 12, .child_index = 861 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 863 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 864 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 865 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 866 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 512 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 867 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 868 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 869 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 870 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 871 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 872 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 873 },
    .{ .char = 't', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 874 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 875 },
    .{ .char = 'e', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 425 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 876 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 877 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 878 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 879 },
    .{ .char = '2', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 880 },
    .{ .char = '4', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = '8', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 882 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 883 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 884 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 773 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 885 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 886 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 887 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 888 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 889 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 890 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 891 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 892 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 894 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 894 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 894 },
    .{ .char = '1', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 896 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 897 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 899 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 387 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 900 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 387 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 387 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 901 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 901 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 789 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 683 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 605 },
    .{ .char = 'c', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'm', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'p', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'z', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 902 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 605 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 903 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 669 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 904 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 527 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 527 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 527 },
    .{ .char = 'l', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'r', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 905 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 906 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 807 },
    .{ .char = 'x', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 558 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 908 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 7, .child_index = 909 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 912 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 527 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 527 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 914 },
    .{ .char = 'z', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 916 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 40, .child_index = 921 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 925 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 926 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 926 },
    .{ .char = 'z', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 916 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 927 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 928 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 10, .child_index = 930 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 143 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 932 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 934 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 935 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 936 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 939 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 940 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 936 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 941 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 14, .child_index = 942 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 945 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 946 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 527 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 947 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 949 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 951 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 387 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 952 },
    .{ .char = 'b', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'd', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'h', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 956 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 957 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 958 },
    .{ .char = 'o', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'v', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 959 },
    .{ .char = 'o', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'v', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 962 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 7, .child_index = 909 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 963 },
    .{ .char = 'k', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 966 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 968 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 969 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 269 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 970 },
    .{ .char = '8', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 971 },
    .{ .char = '4', .end_of_word = true, .end_of_list = true, .number = 3, .child_index = 972 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 655 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 974 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 975 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 976 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 978 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 980 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 981 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 982 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 983 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 676 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 986 },
    .{ .char = 'z', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 987 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 670 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 988 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 989 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 990 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 991 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 678 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 992 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 780 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 993 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 353 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 994 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 995 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 996 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 996 },
    .{ .char = '6', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 997 },
    .{ .char = 'p', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 998 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 998 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 999 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1000 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 605 },
    .{ .char = 'v', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 1001 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1005 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 512 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 512 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 1006 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1011 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 1012 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 1013 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 1013 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 959 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 959 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 530 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 530 },
    .{ .char = 'b', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'd', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'h', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 610 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 1016 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 10, .child_index = 1017 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = false, .number = 18, .child_index = 1018 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 10, .child_index = 1020 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 1021 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 181 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1022 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 1024 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 934 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = false, .number = 5, .child_index = 1025 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 1026 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 1029 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 3, .child_index = 1031 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 847 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 847 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 387 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 1033 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 959 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1037 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 939 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 1038 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 6, .child_index = 912 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 1022 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 6, .child_index = 912 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1041 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 958 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 1042 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1042 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 1044 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1044 },
    .{ .char = 'y', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 1045 },
    .{ .char = 'm', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'n', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'p', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'z', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 246 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1046 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1047 },
    .{ .char = 'b', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'h', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 1048 },
    .{ .char = '2', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 1050 },
    .{ .char = '4', .end_of_word = false, .end_of_list = false, .number = 3, .child_index = 1051 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 998 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 1053 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 1053 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1055 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 1057 },
    .{ .char = '2', .end_of_word = true, .end_of_list = true, .number = 4, .child_index = 1058 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 387 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 387 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1060 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1061 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1062 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 1063 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 1064 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 982 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1065 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 1066 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1067 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 387 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 1068 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 1069 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 311 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1070 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1071 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1072 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1073 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1074 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1075 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 512 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 143 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1076 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1077 },
    .{ .char = 'p', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 1078 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1079 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 181 },
    .{ .char = '1', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1080 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 181 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 246 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 246 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 246 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 246 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1081 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 246 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 246 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 246 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 246 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 246 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1082 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 344 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 181 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 181 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 181 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 996 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = true, .number = 10, .child_index = 1084 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 1016 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 16, .child_index = 1086 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 10, .child_index = 1089 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 1033 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 344 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 344 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 1094 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 1095 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 1096 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 1096 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1097 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 527 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 527 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 527 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 527 },
    .{ .char = 'b', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'd', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'h', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1098 },
    .{ .char = 'm', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 1099 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 1100 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 1101 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 847 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 181 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 181 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 181 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 1103 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 934 },
    .{ .char = '4', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1106 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 1107 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 1107 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 998 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 1109 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1111 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 527 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 959 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 646 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 888 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 869 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 387 },
    .{ .char = 's', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 971 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 387 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 353 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1112 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1113 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 1114 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1115 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 1116 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1119 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 293 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1120 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1121 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 130 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1122 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 249 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1123 },
    .{ .char = 'k', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 130 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1124 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1125 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 387 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 248 },
    .{ .char = '6', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1126 },
    .{ .char = 'h', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 996 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 8, .child_index = 1127 },
    .{ .char = 'f', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 996 },
    .{ .char = 's', .end_of_word = false, .end_of_list = false, .number = 7, .child_index = 1132 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 7, .child_index = 1132 },
    .{ .char = 'b', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 1078 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 1136 },
    .{ .char = 'h', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 1078 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 1078 },
    .{ .char = 'z', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 959 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 3, .child_index = 1137 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 1140 },
    .{ .char = '2', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1141 },
    .{ .char = '2', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 143 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1143 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 246 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1144 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 246 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1144 },
    .{ .char = 'd', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'q', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 669 },
    .{ .char = 'l', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 1078 },
    .{ .char = 'r', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 1078 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 181 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 181 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 181 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1146 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1147 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 1148 },
    .{ .char = 'g', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = false, .number = 4, .child_index = 1149 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 1151 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1152 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 353 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 311 },
    .{ .char = 'i', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1153 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 248 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1154 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1155 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1156 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1157 },
    .{ .char = 'b', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 1078 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 1136 },
    .{ .char = 'h', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 1078 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 1136 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 1078 },
    .{ .char = 'b', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 1078 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 1136 },
    .{ .char = 'h', .end_of_word = true, .end_of_list = false, .number = 2, .child_index = 1078 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 1078 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 387 },
    .{ .char = 'b', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 246 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 246 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 246 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 5, .child_index = 1006 },
    .{ .char = 'd', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 'w', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'h', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 181 },
    .{ .char = 'm', .end_of_word = true, .end_of_list = false, .number = 1, .child_index = 0 },
    .{ .char = 's', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = '1', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1158 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1159 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 4, .child_index = 1160 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = false, .number = 2, .child_index = 1164 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1164 },
    .{ .char = 'r', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 1165 },
    .{ .char = 'w', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1166 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1167 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1168 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1169 },
    .{ .char = 'r', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1170 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1171 },
    .{ .char = '2', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1172 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1152 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 1173 },
    .{ .char = 'g', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 171 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = false, .number = 1, .child_index = 171 },
    .{ .char = 'u', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 535 },
    .{ .char = 'd', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 1165 },
    .{ .char = 'l', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 387 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 2, .child_index = 1174 },
    .{ .char = 'n', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1175 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1176 },
    .{ .char = 'c', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1177 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1178 },
    .{ .char = 'o', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1179 },
    .{ .char = '8', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'q', .end_of_word = true, .end_of_list = true, .number = 1, .child_index = 0 },
    .{ .char = 'p', .end_of_word = true, .end_of_list = true, .number = 2, .child_index = 1165 },
    .{ .char = 'a', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 350 },
    .{ .char = 's', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 181 },
    .{ .char = 't', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1180 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1181 },
    .{ .char = 'd', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 143 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1182 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1183 },
    .{ .char = 'e', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1184 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1185 },
    .{ .char = 'x', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1186 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1187 },
    .{ .char = 'p', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1173 },
    .{ .char = '_', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 1188 },
    .{ .char = 'q', .end_of_word = false, .end_of_list = true, .number = 1, .child_index = 387 },
};
pub const data = blk: {
    @setEvalBranchQuota(5103);
    break :blk [_]Properties{
        .{ .param_str = "LLdLLdLLd", .features = "float128" },
        .{ .param_str = "UiUiUi", .features = "isa_v206_instructions" },
        .{ .param_str = "vUIi", .features = "altivec" },
        .{ .param_str = "v", .features = "altivec" },
        .{ .param_str = "vvC*iUIi", .features = "altivec" },
        .{ .param_str = "vvC*iUIi", .features = "altivec" },
        .{ .param_str = "vvC*iUIi", .features = "altivec" },
        .{ .param_str = "vvC*iUIi", .features = "altivec" },
        .{ .param_str = "V16cLivC*", .features = "altivec" },
        .{ .param_str = "V8sLivC*", .features = "altivec" },
        .{ .param_str = "V4iLivC*", .features = "altivec" },
        .{ .param_str = "V16cUcvC*", .features = "altivec" },
        .{ .param_str = "V16cUcvC*", .features = "altivec" },
        .{ .param_str = "V4iLivC*", .features = "altivec" },
        .{ .param_str = "V4iLivC*", .features = "altivec" },
        .{ .param_str = "V8Us", .features = "altivec" },
        .{ .param_str = "vV4i", .features = "altivec" },
        .{ .param_str = "V16UcULLi", .features = "power10_vector" },
        .{ .param_str = "V2ULLiULLi", .features = "power10_vector" },
        .{ .param_str = "V8UsULLi", .features = "power10_vector" },
        .{ .param_str = "V1ULLLiULLi", .features = "power10_vector" },
        .{ .param_str = "V4UiULLi", .features = "power10_vector" },
        .{ .param_str = "vV16cLiv*", .features = "altivec" },
        .{ .param_str = "vV8sLiv*", .features = "altivec" },
        .{ .param_str = "vV4iLiv*", .features = "altivec" },
        .{ .param_str = "vV4iLiv*", .features = "altivec" },
        .{ .param_str = "vV4iLiv*", .features = "altivec" },
        .{ .param_str = "V8UsV8UsV8Us", .features = "power9_vector" },
        .{ .param_str = "V4UiV4UiV4Ui", .features = "power9_vector" },
        .{ .param_str = "V4UiV4UiV4Ui", .features = "altivec" },
        .{ .param_str = "V16ScV16ScV16Sc", .features = "altivec" },
        .{ .param_str = "V8SsV8SsV8Ss", .features = "altivec" },
        .{ .param_str = "V4SiV4SiV4Si", .features = "altivec" },
        .{ .param_str = "V16UcV16UcV16Uc", .features = "altivec" },
        .{ .param_str = "V8UsV8UsV8Us", .features = "altivec" },
        .{ .param_str = "V4UiV4UiV4Ui", .features = "altivec" },
        .{ .param_str = "V16ScV16ScV16Sc", .features = "altivec" },
        .{ .param_str = "V8SsV8SsV8Ss", .features = "altivec" },
        .{ .param_str = "V4SiV4SiV4Si", .features = "altivec" },
        .{ .param_str = "V16UcV16UcV16Uc", .features = "altivec" },
        .{ .param_str = "V8UsV8UsV8Us", .features = "altivec" },
        .{ .param_str = "V4UiV4UiV4Ui", .features = "altivec" },
        .{ .param_str = "V4fV4SiIi", .features = "altivec" },
        .{ .param_str = "V4fV4UiIi", .features = "altivec" },
        .{ .param_str = "V16UcV16UcUi", .features = "power10_vector" },
        .{ .param_str = "V16UcV16UcUi", .features = "power10_vector" },
        .{ .param_str = "V16UcV16Uc", .features = "power8_vector" },
        .{ .param_str = "V2ULLiV2ULLi", .features = "power8_vector" },
        .{ .param_str = "V8UsV8Us", .features = "power8_vector" },
        .{ .param_str = "SiV16Uc", .features = "power9_vector" },
        .{ .param_str = "V4UiV4Ui", .features = "power8_vector" },
        .{ .param_str = "V4iV4fV4f", .features = "altivec" },
        .{ .param_str = "iiV4fV4f", .features = "altivec" },
        .{ .param_str = "V4iV4fV4f", .features = "altivec" },
        .{ .param_str = "iiV4fV4f", .features = "altivec" },
        .{ .param_str = "V16cV16cV16c", .features = "altivec" },
        .{ .param_str = "iiV16cV16c", .features = "altivec" },
        .{ .param_str = "iiV2LLiV2LLi", .features = "vsx" },
        .{ .param_str = "V8sV8sV8s", .features = "altivec" },
        .{ .param_str = "iiV8sV8s", .features = "altivec" },
        .{ .param_str = "iiV1ULLLiV1LLLi", .features = "altivec" },
        .{ .param_str = "V4iV4iV4i", .features = "altivec" },
        .{ .param_str = "iiV4iV4i", .features = "altivec" },
        .{ .param_str = "V4iV4fV4f", .features = "altivec" },
        .{ .param_str = "iiV4fV4f", .features = "altivec" },
        .{ .param_str = "V4iV4fV4f", .features = "altivec" },
        .{ .param_str = "iiV4fV4f", .features = "altivec" },
        .{ .param_str = "V16cV16ScV16Sc", .features = "altivec" },
        .{ .param_str = "iiV16ScV16Sc", .features = "altivec" },
        .{ .param_str = "iiV2LLiV2LLi", .features = "vsx" },
        .{ .param_str = "V8sV8SsV8Ss", .features = "altivec" },
        .{ .param_str = "iiV8SsV8Ss", .features = "altivec" },
        .{ .param_str = "V4iV4SiV4Si", .features = "altivec" },
        .{ .param_str = "iiV4SiV4Si", .features = "altivec" },
        .{ .param_str = "V16cV16UcV16Uc", .features = "altivec" },
        .{ .param_str = "iiV16UcV16Uc", .features = "altivec" },
        .{ .param_str = "iiV2ULLiV2ULLi", .features = "vsx" },
        .{ .param_str = "V8sV8UsV8Us", .features = "altivec" },
        .{ .param_str = "iiV8UsV8Us", .features = "altivec" },
        .{ .param_str = "V4iV4UiV4Ui", .features = "altivec" },
        .{ .param_str = "iiV4UiV4Ui", .features = "altivec" },
        .{ .param_str = "V16cV16cV16c", .features = "power9_vector" },
        .{ .param_str = "iiV16cV16c", .features = "power9_vector" },
        .{ .param_str = "iiV2LLiV2LLi", .features = "vsx" },
        .{ .param_str = "V8sV8sV8s", .features = "power9_vector" },
        .{ .param_str = "iiV8sV8s", .features = "power9_vector" },
        .{ .param_str = "V4iV4iV4i", .features = "power9_vector" },
        .{ .param_str = "iiV4iV4i", .features = "power9_vector" },
        .{ .param_str = "V16cV16cV16c", .features = "power9_vector" },
        .{ .param_str = "V8sV8sV8s", .features = "power9_vector" },
        .{ .param_str = "V4iV4iV4i", .features = "power9_vector" },
        .{ .param_str = "ULLiV16UcUi", .features = "power10_vector" },
        .{ .param_str = "ULLiV2ULLiUi", .features = "power10_vector" },
        .{ .param_str = "ULLiV8UsUi", .features = "power10_vector" },
        .{ .param_str = "ULLiV4UiUi", .features = "power10_vector" },
        .{ .param_str = "V4SiV4fIi", .features = "altivec" },
        .{ .param_str = "V4UiV4fIi", .features = "altivec" },
        .{ .param_str = "V16UcV16Uc", .features = "power9_vector" },
        .{ .param_str = "V2ULLiV2ULLi", .features = "power9_vector" },
        .{ .param_str = "V8UsV8Us", .features = "power9_vector" },
        .{ .param_str = "SiV16Uc", .features = "power9_vector" },
        .{ .param_str = "V4UiV4Ui", .features = "power9_vector" },
        .{ .param_str = "V4SiV4SiV4Si", .features = "power10_vector" },
        .{ .param_str = "V4UiV4UiV4Ui", .features = "power10_vector" },
        .{ .param_str = "V16UcV16Uc", .features = "power10_vector" },
        .{ .param_str = "V8UsV8Us", .features = "power10_vector" },
        .{ .param_str = "V4UiV4Ui", .features = "power10_vector" },
        .{ .param_str = "V4fV4f", .features = "altivec" },
        .{ .param_str = "UiV16Uc", .features = "power10_vector" },
        .{ .param_str = "UiV2ULLi", .features = "power10_vector" },
        .{ .param_str = "UiV8Us", .features = "power10_vector" },
        .{ .param_str = "UiV1ULLLi", .features = "power10_vector" },
        .{ .param_str = "UiV4Ui", .features = "power10_vector" },
        .{ .param_str = "V2SLLiV16Sc", .features = "power9_vector" },
        .{ .param_str = "V4SiV16Sc", .features = "power9_vector" },
        .{ .param_str = "V2SLLiV8Ss", .features = "power9_vector" },
        .{ .param_str = "V4SiV8Ss", .features = "power9_vector" },
        .{ .param_str = "V2SLLiV4Si", .features = "power9_vector" },
        .{ .param_str = "V16UcV16Uc", .features = "power8_vector" },
        .{ .param_str = "ULLiV1ULLLiIi", .features = "power10_vector" },
        .{ .param_str = "V8UsV8UsUiUi", .features = "power10_vector" },
        .{ .param_str = "V8UsV8UsUiUi", .features = "power10_vector" },
        .{ .param_str = "V16UcV16UcUiIi", .features = "power10_vector" },
        .{ .param_str = "V4UiV4UiUiUi", .features = "power10_vector" },
        .{ .param_str = "V4UiV4UiUiUi", .features = "power10_vector" },
        .{ .param_str = "V4fV4f", .features = "altivec" },
        .{ .param_str = "V4fV4fV4fV4f", .features = "altivec" },
        .{ .param_str = "V4fV4fV4f", .features = "altivec" },
        .{ .param_str = "V16ScV16ScV16Sc", .features = "altivec" },
        .{ .param_str = "V2LLiV2LLiV2LLi", .features = "power8_vector" },
        .{ .param_str = "V8SsV8SsV8Ss", .features = "altivec" },
        .{ .param_str = "V4SiV4SiV4Si", .features = "altivec" },
        .{ .param_str = "V16UcV16UcV16Uc", .features = "altivec" },
        .{ .param_str = "V8UsV8UsV8Us", .features = "altivec" },
        .{ .param_str = "V4UiV4UiV4Ui", .features = "altivec" },
        .{ .param_str = "V8sV8sV8sV8s", .features = "altivec" },
        .{ .param_str = "V8sV8sV8sV8s", .features = "altivec" },
        .{ .param_str = "V4fV4fV4f", .features = "altivec" },
        .{ .param_str = "V16ScV16ScV16Sc", .features = "altivec" },
        .{ .param_str = "V2LLiV2LLiV2LLi", .features = "power8_vector" },
        .{ .param_str = "V8SsV8SsV8Ss", .features = "altivec" },
        .{ .param_str = "V4SiV4SiV4Si", .features = "altivec" },
        .{ .param_str = "V16UcV16UcV16Uc", .features = "altivec" },
        .{ .param_str = "V8UsV8UsV8Us", .features = "altivec" },
        .{ .param_str = "V4UiV4UiV4Ui", .features = "altivec" },
        .{ .param_str = "V4SiV16ScV16UcV4Si", .features = "altivec" },
        .{ .param_str = "V4SiV8SsV8SsV4Si", .features = "altivec" },
        .{ .param_str = "V4SiV8SsV8SsV4Si", .features = "altivec" },
        .{ .param_str = "V4UiV16UcV16UcV4Ui", .features = "altivec" },
        .{ .param_str = "V4UiV8UsV8UsV4Ui", .features = "altivec" },
        .{ .param_str = "V4UiV8UsV8UsV4Ui", .features = "altivec" },
        .{ .param_str = "V8SsV16ScV16Sc", .features = "altivec" },
        .{ .param_str = "V4SiV8SsV8Ss", .features = "altivec" },
        .{ .param_str = "V2SLLiV4SiV4Si", .features = "power8_vector" },
        .{ .param_str = "V8UsV16UcV16Uc", .features = "altivec" },
        .{ .param_str = "V4UiV8UsV8Us", .features = "altivec" },
        .{ .param_str = "V2ULLiV4UiV4Ui", .features = "power8_vector" },
        .{ .param_str = "V4SiV4SiV4Si", .features = "power10_vector" },
        .{ .param_str = "V4UiV4UiV4Ui", .features = "power10_vector" },
        .{ .param_str = "V8SsV16ScV16Sc", .features = "altivec" },
        .{ .param_str = "V4SiV8SsV8Ss", .features = "altivec" },
        .{ .param_str = "V2SLLiV4SiV4Si", .features = "power8_vector" },
        .{ .param_str = "V8UsV16UcV16Uc", .features = "altivec" },
        .{ .param_str = "V4UiV8UsV8Us", .features = "altivec" },
        .{ .param_str = "V2ULLiV4UiV4Ui", .features = "power8_vector" },
        .{ .param_str = "V4fV4fV4fV4f", .features = "altivec" },
        .{ .param_str = "V4iV4iV4iV16Uc", .features = "altivec" },
        .{ .param_str = "V8sV4UiV4Ui", .features = "altivec" },
        .{ .param_str = "V16ScV8SsV8Ss", .features = "altivec" },
        .{ .param_str = "V16UcV8SsV8Ss", .features = "altivec" },
        .{ .param_str = "V8SsV4SiV4Si", .features = "altivec" },
        .{ .param_str = "V8UsV4SiV4Si", .features = "altivec" },
        .{ .param_str = "V16UcV8UsV8Us", .features = "altivec" },
        .{ .param_str = "V8UsV4UiV4Ui", .features = "altivec" },
        .{ .param_str = "V2ULLiV2ULLi", .features = "power9_vector" },
        .{ .param_str = "V1ULLLiV1ULLLi", .features = "power9_vector" },
        .{ .param_str = "V4UiV4Ui", .features = "power9_vector" },
        .{ .param_str = "V4fV4f", .features = "altivec" },
        .{ .param_str = "V4fV4f", .features = "altivec" },
        .{ .param_str = "V4fV4f", .features = "altivec" },
        .{ .param_str = "V4fV4f", .features = "altivec" },
        .{ .param_str = "V4fV4f", .features = "altivec" },
        .{ .param_str = "V16cV16cV16Uc", .features = "altivec" },
        .{ .param_str = "V2LLiV2LLiV2ULLi", .features = "power8_vector" },
        .{ .param_str = "V8sV8sV8Us", .features = "altivec" },
        .{ .param_str = "V4iV4iV4Ui", .features = "altivec" },
        .{ .param_str = "V4UiV4UiV4Ui", .features = "power9_vector" },
        .{ .param_str = "V4fV4f", .features = "altivec" },
        .{ .param_str = "V4iV4iV4iV4Ui", .features = "altivec" },
        .{ .param_str = "V4iV4iV4i", .features = "altivec" },
        .{ .param_str = "V4iV4iV4i", .features = "altivec" },
        .{ .param_str = "V16UcV16UcV16Uc", .features = "power9_vector" },
        .{ .param_str = "V4iV4iV4i", .features = "altivec" },
        .{ .param_str = "V16cV16cV16Uc", .features = "altivec" },
        .{ .param_str = "V8sV8sV8Us", .features = "altivec" },
        .{ .param_str = "V4iV4iV4Ui", .features = "altivec" },
        .{ .param_str = "V4iV4iV4i", .features = "altivec" },
        .{ .param_str = "V16UcV16UcV16Uc", .features = "power9_vector" },
        .{ .param_str = "V16UcV16Uc", .features = "power10_vector" },
        .{ .param_str = "iiV16Uc", .features = "power10_vector" },
        .{ .param_str = "V16UcV16Uc", .features = "power10_vector" },
        .{ .param_str = "iiV16Uc", .features = "power10_vector" },
        .{ .param_str = "V8sV8s", .features = "power10_vector" },
        .{ .param_str = "iiV8s", .features = "power10_vector" },
        .{ .param_str = "V8sV8s", .features = "power10_vector" },
        .{ .param_str = "iiV8s", .features = "power10_vector" },
        .{ .param_str = "V4UiV4UiV4Ui", .features = "altivec" },
        .{ .param_str = "V16ScV16ScV16Sc", .features = "altivec" },
        .{ .param_str = "V8SsV8SsV8Ss", .features = "altivec" },
        .{ .param_str = "V4SiV4SiV4Si", .features = "altivec" },
        .{ .param_str = "V16UcV16UcV16Uc", .features = "altivec" },
        .{ .param_str = "V8UsV8UsV8Us", .features = "altivec" },
        .{ .param_str = "V4UiV4UiV4Ui", .features = "altivec" },
        .{ .param_str = "V4SiV4SiV4Si", .features = "altivec" },
        .{ .param_str = "V4SiV16ScV4Si", .features = "altivec" },
        .{ .param_str = "V4SiV8SsV4Si", .features = "altivec" },
        .{ .param_str = "V4UiV16UcV4Ui", .features = "altivec" },
        .{ .param_str = "V4SiV4SiV4Si", .features = "altivec" },
        .{ .param_str = "V4UiV8s", .features = "altivec" },
        .{ .param_str = "V8sV16c", .features = "altivec" },
        .{ .param_str = "V4iV8s", .features = "altivec" },
        .{ .param_str = "V2LLiV4i", .features = "power8_vector" },
        .{ .param_str = "V4UiV8s", .features = "altivec" },
        .{ .param_str = "V8sV16c", .features = "altivec" },
        .{ .param_str = "V4iV8s", .features = "altivec" },
        .{ .param_str = "V2LLiV4i", .features = "power8_vector" },
        .{ .param_str = "SLLiSLLiSLLi", .features = "bpermd" },
        .{ .param_str = "UiUi", .features = "isa_v206_instructions" },
        .{ .param_str = "UiUi", .features = "isa_v206_instructions" },
        .{ .param_str = "ULLiULLiULLi", .features = "isa_v31_instructions" },
        .{ .param_str = "ULLiULLiULLi", .features = "isa_v31_instructions" },
        .{ .param_str = "ULLiULLiULLi", .features = "isa_v31_instructions" },
        .{ .param_str = "LLi", .features = "isa_v30_instructions" },
        .{ .param_str = "i", .features = "isa_v30_instructions" },
        .{ .param_str = "LLi", .features = "isa_v30_instructions" },
        .{ .param_str = "vvC*" },
        .{ .param_str = "SLLiSLLiSLLi", .features = "extdiv" },
        .{ .param_str = "ULLiULLiULLi", .features = "extdiv" },
        .{ .param_str = "LLdLLdLLd", .features = "float128" },
        .{ .param_str = "SiSiSi", .features = "extdiv" },
        .{ .param_str = "UiUiUi", .features = "extdiv" },
        .{ .param_str = "LLdLLdLLdLLd", .features = "float128" },
        .{ .param_str = "LUi", .attributes = .{ .@"const" = true }, .features = "htm" },
        .{ .param_str = "LUi", .attributes = .{ .@"const" = true }, .features = "htm" },
        .{ .param_str = "LUi", .attributes = .{ .@"const" = true }, .features = "htm" },
        .{ .param_str = "LUi", .attributes = .{ .@"const" = true }, .features = "htm" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "mma,paired_vector_memops" },
        .{ .param_str = "LLdLLdLLd", .features = "float128" },
        .{ .param_str = "Lddd" },
        .{ .param_str = "V1LLLiULLiULLi", .features = "vsx" },
        .{ .param_str = "ULLiULLiULLi", .features = "isa_v31_instructions" },
        .{ .param_str = "ULLiULLiULLi", .features = "isa_v31_instructions" },
        .{ .param_str = "LLiLLiLLiCIi", .features = "isa_v30_instructions" },
        .{ .param_str = "LLiLLiLLi", .features = "isa_v206_instructions" },
        .{ .param_str = "vIivC*", .attributes = .{ .@"const" = true } },
        .{ .param_str = "LLiLLi", .features = "isa_v206_instructions" },
        .{ .param_str = "LLiLLi", .features = "isa_v206_instructions" },
        .{ .param_str = "LLiLLiLLi" },
        .{ .param_str = "LLiLLiLLi", .features = "isa_v30_instructions" },
        .{ .param_str = "iCIiii", .features = "isa_v30_instructions" },
        .{ .param_str = "iiD*i*i" },
        .{ .param_str = "iLiD*Li*Li" },
        .{ .param_str = "idd", .features = "isa_v30_instructions,vsx" },
        .{ .param_str = "idd", .features = "isa_v30_instructions,vsx" },
        .{ .param_str = "idd", .features = "isa_v30_instructions,vsx" },
        .{ .param_str = "idd", .features = "isa_v30_instructions,vsx" },
        .{ .param_str = "vvC*" },
        .{ .param_str = "vvC*" },
        .{ .param_str = "vvC*" },
        .{ .param_str = "vv*" },
        .{ .param_str = "vv*" },
        .{ .param_str = "vv*" },
        .{ .param_str = "vv*" },
        .{ .param_str = "vv*" },
        .{ .param_str = "v" },
        .{ .param_str = "Uid", .features = "power9_vector" },
        .{ .param_str = "ULLid", .features = "power9_vector" },
        .{ .param_str = "dd" },
        .{ .param_str = "dd" },
        .{ .param_str = "dd" },
        .{ .param_str = "dd" },
        .{ .param_str = "dd" },
        .{ .param_str = "dd" },
        .{ .param_str = "dd" },
        .{ .param_str = "dd" },
        .{ .param_str = "v" },
        .{ .param_str = "iiD*i" },
        .{ .param_str = "LiLiD*Li" },
        .{ .param_str = "UiUiD*Ui" },
        .{ .param_str = "ULiULiD*ULi" },
        .{ .param_str = "UiUiD*Ui" },
        .{ .param_str = "ULiULiD*ULi" },
        .{ .param_str = "UiUiD*Ui" },
        .{ .param_str = "ULiULiD*ULi" },
        .{ .param_str = "dddd" },
        .{ .param_str = "ffff" },
        .{ .param_str = "dd" },
        .{ .param_str = "ff" },
        .{ .param_str = "dddd" },
        .{ .param_str = "ffff" },
        .{ .param_str = "dddd" },
        .{ .param_str = "ffff" },
        .{ .param_str = "dd" },
        .{ .param_str = "ff" },
        .{ .param_str = "dd" },
        .{ .param_str = "dd" },
        .{ .param_str = "ff" },
        .{ .param_str = "dd" },
        .{ .param_str = "ff" },
        .{ .param_str = "dd" },
        .{ .param_str = "ff" },
        .{ .param_str = "dd" },
        .{ .param_str = "ff" },
        .{ .param_str = "dd" },
        .{ .param_str = "ff" },
        .{ .param_str = "dddd" },
        .{ .param_str = "ffff" },
        .{ .param_str = "dd" },
        .{ .param_str = "ff" },
        .{ .param_str = "ULLi" },
        .{ .param_str = "vv*", .features = "isa_v207_instructions" },
        .{ .param_str = "ddULLi", .features = "power9_vector" },
        .{ .param_str = "v" },
        .{ .param_str = "v" },
        .{ .param_str = "v" },
        .{ .param_str = "v" },
        .{ .param_str = "ccD*", .features = "isa_v207_instructions" },
        .{ .param_str = "LiLiD*" },
        .{ .param_str = "ssD*", .features = "isa_v207_instructions" },
        .{ .param_str = "UsUs*" },
        .{ .param_str = "UiUi*" },
        .{ .param_str = "ULLiULLi*", .features = "isa_v206_instructions" },
        .{ .param_str = "iiD*" },
        .{ .param_str = "v" },
        .{ .param_str = "LLiLLiLLiLLi", .features = "isa_v30_instructions" },
        .{ .param_str = "LLiLLiLLiLLi", .features = "isa_v30_instructions" },
        .{ .param_str = "LdLdLdLd.", .attributes = .{ .custom_typecheck = true } },
        .{ .param_str = "dddd.", .attributes = .{ .custom_typecheck = true } },
        .{ .param_str = "ffff.", .attributes = .{ .custom_typecheck = true } },
        .{ .param_str = "d" },
        .{ .param_str = "d", .features = "isa_v30_instructions" },
        .{ .param_str = "Ui" },
        .{ .param_str = "ULiIi" },
        .{ .param_str = "Ui" },
        .{ .param_str = "LdLdLdLd.", .attributes = .{ .custom_typecheck = true } },
        .{ .param_str = "dddd.", .attributes = .{ .custom_typecheck = true } },
        .{ .param_str = "ffff.", .attributes = .{ .custom_typecheck = true } },
        .{ .param_str = "vUIi" },
        .{ .param_str = "vUIi" },
        .{ .param_str = "vUIiUi" },
        .{ .param_str = "vUIiUIi" },
        .{ .param_str = "vUi" },
        .{ .param_str = "vIiULi" },
        .{ .param_str = "LLiLiLi" },
        .{ .param_str = "ULLiULiULi" },
        .{ .param_str = "iii" },
        .{ .param_str = "UiUiUi" },
        .{ .param_str = "V16UcV16UcUc", .attributes = .{ .custom_typecheck = true }, .features = "power9_vector" },
        .{ .param_str = "V16UcV16Uc", .features = "power9_vector" },
        .{ .param_str = "V16UcV16UcUc", .attributes = .{ .custom_typecheck = true }, .features = "power9_vector" },
        .{ .param_str = "ULiULi" },
        .{ .param_str = "iUi" },
        .{ .param_str = "iULLi" },
        .{ .param_str = "UWiUWiUWiUWIi", .attributes = .{ .@"const" = true } },
        .{ .param_str = "V2dV2dV2d" },
        .{ .param_str = "V4fV4fV4f" },
        .{ .param_str = "ULLiULLiULLiIUiIULLi" },
        .{ .param_str = "UiUiUiIUiIUi" },
        .{ .param_str = "UiUiUiIUi" },
        .{ .param_str = "V2dV2d" },
        .{ .param_str = "V4fV4f" },
        .{ .param_str = "di" },
        .{ .param_str = "LLiLLiLLi", .features = "isa_v30_instructions" },
        .{ .param_str = "icD*i", .features = "isa_v207_instructions" },
        .{ .param_str = "iLiD*Li" },
        .{ .param_str = "viC*d" },
        .{ .param_str = "isD*s", .features = "isa_v207_instructions" },
        .{ .param_str = "vUiUs*" },
        .{ .param_str = "vUiUi*" },
        .{ .param_str = "vULLiULLi*", .features = "isa_v206_instructions" },
        .{ .param_str = "iiD*i" },
        .{ .param_str = "ddd" },
        .{ .param_str = "ddd" },
        .{ .param_str = "fff" },
        .{ .param_str = "fff" },
        .{ .param_str = "v" },
        .{ .param_str = "vLLiLLiIUi" },
        .{ .param_str = "idIi", .attributes = .{ .custom_typecheck = true }, .features = "isa_v30_instructions,vsx" },
        .{ .param_str = "vi" },
        .{ .param_str = "vLi" },
        .{ .param_str = "viiIUi" },
        .{ .param_str = "V16UcV16UcUc", .attributes = .{ .custom_typecheck = true }, .features = "power9_vector" },
        .{ .param_str = "d" },
        .{ .param_str = "vLUi", .attributes = .{ .@"const" = true }, .features = "htm" },
        .{ .param_str = "vLUi", .attributes = .{ .@"const" = true }, .features = "htm" },
        .{ .param_str = "vLUi", .attributes = .{ .@"const" = true }, .features = "htm" },
        .{ .param_str = "vLUi", .attributes = .{ .@"const" = true }, .features = "htm" },
        .{ .param_str = "dd" },
        .{ .param_str = "di" },
        .{ .param_str = "LLdLLd", .features = "float128" },
        .{ .param_str = "LLdLLdLLd", .features = "float128" },
        .{ .param_str = "UiUi", .features = "htm" },
        .{ .param_str = "UiUiUiUi", .features = "htm" },
        .{ .param_str = "UiUiUii", .features = "htm" },
        .{ .param_str = "UiUiUiUi", .features = "htm" },
        .{ .param_str = "UiUiUii", .features = "htm" },
        .{ .param_str = "UiUIi", .features = "htm" },
        .{ .param_str = "Ui", .features = "htm" },
        .{ .param_str = "UiUIi", .features = "htm" },
        .{ .param_str = "Ui", .features = "htm" },
        .{ .param_str = "Ui", .features = "htm" },
        .{ .param_str = "UiUi", .features = "htm" },
        .{ .param_str = "Ui", .features = "htm" },
        .{ .param_str = "dLLd", .features = "float128" },
        .{ .param_str = "UiUi", .features = "htm" },
        .{ .param_str = "Ui", .features = "htm" },
        .{ .param_str = "LUi", .features = "htm" },
        .{ .param_str = "dLdIi" },
        .{ .param_str = "ULLiV1LLLii", .features = "vsx" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "paired_vector_memops" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "paired_vector_memops" },
        .{ .param_str = "V2ULLiV16UcIi", .features = "vsx" },
        .{ .param_str = "V16UcV4UiV16UcIi", .features = "vsx" },
        .{ .param_str = "V16UcCc*Ii", .features = "isa_v207_instructions" },
        .{ .param_str = "V2dLivC*", .features = "vsx" },
        .{ .param_str = "V2dSLLivC*", .features = "vsx" },
        .{ .param_str = "V4ivC*ULLi", .features = "power9_vector" },
        .{ .param_str = "V4ivC*ULLi", .features = "power9_vector" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "paired_vector_memops" },
        .{ .param_str = "V4iLivC*", .features = "vsx" },
        .{ .param_str = "V4iSLLivC*", .features = "vsx" },
        .{ .param_str = "ULLiLLd", .features = "float128" },
        .{ .param_str = "LLdLLdULLi", .features = "float128" },
        .{ .param_str = "vCc*IiV16Uc", .features = "isa_v207_instructions" },
        .{ .param_str = "vV2dLiv*", .features = "vsx" },
        .{ .param_str = "vV2dSLLivC*", .features = "vsx" },
        .{ .param_str = "vV4iv*ULLi", .features = "power9_vector" },
        .{ .param_str = "vV4iv*ULLi", .features = "power9_vector" },
        .{ .param_str = "i.", .attributes = .{ .custom_typecheck = true }, .features = "paired_vector_memops" },
        .{ .param_str = "vV4iLiv*", .features = "vsx" },
        .{ .param_str = "vV4iSLLivC*", .features = "vsx" },
        .{ .param_str = "ddd", .features = "vsx" },
        .{ .param_str = "ddd", .features = "vsx" },
        .{ .param_str = "V2dV2d", .features = "vsx" },
        .{ .param_str = "V4fV4f", .features = "vsx" },
        .{ .param_str = "V2ULLiV2dV2d", .features = "vsx" },
        .{ .param_str = "iiV2dV2d", .features = "vsx" },
        .{ .param_str = "V4UiV4fV4f", .features = "vsx" },
        .{ .param_str = "iiV4fV4f", .features = "vsx" },
        .{ .param_str = "V2ULLiV2dV2d", .features = "vsx" },
        .{ .param_str = "iiV2dV2d", .features = "vsx" },
        .{ .param_str = "V4UiV4fV4f", .features = "vsx" },
        .{ .param_str = "iiV4fV4f", .features = "vsx" },
        .{ .param_str = "V2ULLiV2dV2d", .features = "vsx" },
        .{ .param_str = "iiV2dV2d", .features = "vsx" },
        .{ .param_str = "V4UiV4fV4f", .features = "vsx" },
        .{ .param_str = "iiV4fV4f", .features = "vsx" },
        .{ .param_str = "V2dV2dV2d", .features = "vsx" },
        .{ .param_str = "V4fV4fV4f", .features = "vsx" },
        .{ .param_str = "V16UcV16Uc", .features = "power10_vector" },
        .{ .param_str = "V4fV2d", .features = "vsx" },
        .{ .param_str = "V4SiV2d", .features = "vsx" },
        .{ .param_str = "V4UiV2d", .features = "vsx" },
        .{ .param_str = "V4fV8Us", .features = "power9_vector" },
        .{ .param_str = "V16UcV16Uc", .features = "power10_vector" },
        .{ .param_str = "V2dV4f", .features = "vsx" },
        .{ .param_str = "V4fV4f", .features = "power9_vector" },
        .{ .param_str = "V2SLLiV4f", .features = "vsx" },
        .{ .param_str = "V2ULLiV4f", .features = "vsx" },
        .{ .param_str = "V4fV2SLLi", .features = "vsx" },
        .{ .param_str = "V2dV4Si", .features = "vsx" },
        .{ .param_str = "V4fV2ULLi", .features = "vsx" },
        .{ .param_str = "V2dV4Ui", .features = "vsx" },
        .{ .param_str = "V2dV2dV2d", .features = "vsx" },
        .{ .param_str = "V4fV4fV4f", .features = "vsx" },
        .{ .param_str = "V2dV2ULLiV2ULLi", .features = "power9_vector" },
        .{ .param_str = "V4fV4UiV4Ui", .features = "power9_vector" },
        .{ .param_str = "V2dV2dV2dV2d", .features = "vsx" },
        .{ .param_str = "V4fV4fV4fV4f", .features = "vsx" },
        .{ .param_str = "V2dV2dV2d", .features = "vsx" },
        .{ .param_str = "V4fV4fV4f", .features = "vsx" },
        .{ .param_str = "V2dV2dV2d", .features = "vsx" },
        .{ .param_str = "V4fV4fV4f", .features = "vsx" },
        .{ .param_str = "V2dV2dV2dV2d", .features = "vsx" },
        .{ .param_str = "V4fV4fV4fV4f", .features = "vsx" },
        .{ .param_str = "V2dV2dV2d", .features = "vsx" },
        .{ .param_str = "V4fV4fV4f", .features = "vsx" },
        .{ .param_str = "V2dV2dV2dV2d", .features = "vsx" },
        .{ .param_str = "V4fV4fV4fV4f", .features = "vsx" },
        .{ .param_str = "V2dV2dV2dV2d", .features = "vsx" },
        .{ .param_str = "V4fV4fV4fV4f", .features = "vsx" },
        .{ .param_str = "V2dV2d", .features = "vsx" },
        .{ .param_str = "V2dV2d", .features = "vsx" },
        .{ .param_str = "V2dV2d", .features = "vsx" },
        .{ .param_str = "V2dV2d", .features = "vsx" },
        .{ .param_str = "V2dV2d", .features = "vsx" },
        .{ .param_str = "V2dV2d", .features = "vsx" },
        .{ .param_str = "V4fV4f", .features = "vsx" },
        .{ .param_str = "V4fV4f", .features = "vsx" },
        .{ .param_str = "V4fV4f", .features = "vsx" },
        .{ .param_str = "V4fV4f", .features = "vsx" },
        .{ .param_str = "V4fV4f", .features = "vsx" },
        .{ .param_str = "V4fV4f", .features = "vsx" },
        .{ .param_str = "V2dV2d", .features = "vsx" },
        .{ .param_str = "V4fV4f", .features = "vsx" },
        .{ .param_str = "V2dV2d", .features = "vsx" },
        .{ .param_str = "V4fV4f", .features = "vsx" },
        .{ .param_str = "iV2dV2d", .features = "vsx" },
        .{ .param_str = "iV4fV4f", .features = "vsx" },
        .{ .param_str = "iV16UcUi", .features = "power10_vector" },
        .{ .param_str = "iV2d", .features = "vsx" },
        .{ .param_str = "iV4f", .features = "vsx" },
        .{ .param_str = "V2ULLiV2dIi", .features = "power9_vector" },
        .{ .param_str = "V4UiV4fIi", .features = "power9_vector" },
        .{ .param_str = "V2ULLiV2d", .features = "power9_vector" },
        .{ .param_str = "V4UiV4f", .features = "power9_vector" },
        .{ .param_str = "V2ULLiV2d", .features = "power9_vector" },
        .{ .param_str = "V4UiV4f", .features = "power9_vector" },
        .{ .param_str = "V16UcV16Uci", .features = "power10_vector" },
        .{ .param_str = "V2ULLiV2ULLii", .features = "power10_vector" },
        .{ .param_str = "V8UsV8Usi", .features = "power10_vector" },
        .{ .param_str = "V4UiV4Uii", .features = "power10_vector" },
        .{ .param_str = "V4UiV4UiV4Ui", .features = "power8_vector" },
        .{ .param_str = "v.", .attributes = .{ .custom_typecheck = true }, .features = "vsx" },
        .{ .param_str = "v.", .attributes = .{ .custom_typecheck = true }, .features = "vsx" },
    };
};
};
}
